@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 /*
 **  This file was originally written by Steven J. Murdoch, and 
@@ -45,6 +45,9 @@
 #include <QString>
 #include <QFileInfo>
 
+#ifdef Q_WS_MAC 
+#include <Carbon/Carbon.h> 
+#endif 
 
 /** Default constructor */
 HelperProcess::HelperProcess(QObject *parent)
@@ -131,3 +134,17 @@ HelperProcess::isDone() const
   return state() == NotRunning;
 }
 
+void
+HelperProcess::toForeground()
+{
+#if defined(Q_WS_MAC) 
+  ProcessSerialNumber psn;
+  OSStatus st;
+
+  do {
+    st = GetProcessForPID(pid(), &psn);
+  } while(st == -600);
+
+  SetFrontProcess(&psn);
+#endif 
+}
