@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 /*
 **  This file was originally written by Steven J. Murdoch, and 
@@ -58,6 +58,8 @@ public:
   void start(const QString &app, const QStringList &args);
   /** Returns true iff process is not running. */
   bool isDone() const;
+  /** Bring process to foreground */
+  void toForeground();
 
 signals:
   /** Invoked when start() fails. */
