@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -39,6 +39,10 @@
 #include <QTimer>
 #include <QTextStream>
 
+#ifdef Q_WS_MAC
+#include <Carbon/Carbon.h>
+#endif
+
 #define IMG_BWGRAPH        ":/images/16x16/utilities-system-monitor.png"
 #define IMG_CONTROL_PANEL  ":/images/16x16/system-run.png"
 #define IMG_MESSAGELOG     ":/images/16x16/format-justify-fill.png"
@@ -215,6 +219,16 @@ MainWindow::MainWindow()
     show(); 
   /* Optimistically hope that the tray icon gets added. */
   _trayIcon.show();
+
+#if defined(Q_WS_MAC)
+  /* Display OSX dock icon if icon preference is not set to "Tray Only" */
+  if (settings.getIconPref() != VidaliaSettings::Tray) {
+      ProcessSerialNumber psn = { 0, kCurrentProcess };
+      TransformProcessType(&psn, kProcessTransformToForegroundApplication);
+  }
+  /* Vidalia launched in background (LSUIElement=true). Bring to foreground. */
+  VidaliaWindow::setVisible(true);
+#endif
 }
 
 /** Destructor. */
@@ -572,9 +586,15 @@ void
 MainWindow::setTrayIcon(const QString &iconFile)
 {
 #if defined(Q_WS_MAC)
+  VidaliaSettings settings;
   QApplication::setWindowIcon(QPixmap(iconFile));
-#endif
+  /* only display tray icon if icon preference is not set to "Dock Only" */
+  if (settings.getIconPref() != VidaliaSettings::Dock)
+    _trayIcon.setIcon(QIcon(iconFile));
+#else
+  /* always display tray icon for other platforms */
   _trayIcon.setIcon(QIcon(iconFile));
+#endif
 }
 
 /** Respond to a double-click on the tray icon by opening the Control Panel
@@ -595,12 +615,7 @@ MainWindow::launchBrowserFromDirectory()
   QString browserDirectory = settings.getBrowserDirectory();
   QString browserDirectoryFilename = settings.getBrowserExecutable();
 
-  /* Set TZ=UTC (to stop leaking timezone information) and
-   * MOZ_NO_REMOTE=1 (to allow multiple instances of Firefox */
-  QStringList env = QProcess::systemEnvironment();
-  env << "TZ=UTC";
-  env << "MOZ_NO_REMOTE=1";
-  _browserProcess->setEnvironment(env);
+  _browserProcess->setEnvironment(updateBrowserEnv());
 
   /* The browser is in <browserDirectory>/App/Firefox/<browserDirectoryFilename> */
   QString browserExecutable =
@@ -627,12 +642,13 @@ MainWindow::launchBrowserFromDirectory()
   /* Build the command line arguments */
   QStringList commandLine;
   // Is this better or worse than MOZ_NO_REMOTE?
-  //commandLine << "-no-remote";
+  commandLine << "-no-remote";
   commandLine << "-profile";
   commandLine << profileDir;
 
   /* Launch the browser */
   _browserProcess->start(browserExecutable, commandLine);
+  _browserProcess->toForeground();
 }
 
 /** Starts the web browser and IM client, if appropriately configured */
@@ -648,8 +664,9 @@ MainWindow::startSubprocesses()
     launchBrowserFromDirectory();
   } else if (!(subprocess = settings.getBrowserExecutable()).isEmpty()) {
     /* BrowserDirectory is not set, but BrowserExecutable is; use this */
-    _browserProcess->setEnvironment(QProcess::systemEnvironment() << "TZ=UTC");
+    _browserProcess->setEnvironment(updateBrowserEnv());
     _browserProcess->start(subprocess, QStringList());
+    _browserProcess->toForeground();
   }
 
   /* Launch the IM client */
@@ -1000,10 +1017,18 @@ MainWindow::start()
 
   updateTorStatus(Starting);
 
+  // Disable autoconfiguration if there are missing config data
+  if(settings.autoControlPort()) {
+    if(settings.getDataDirectory().isEmpty()) {
+      vWarn("Disabling ControlPort autoconfiguration. DataDirectory is empty!");
+      settings.setAutoControlPort(false);
+    }
+  }
+
   /* Check if Tor is already running separately */
   if(settings.getControlMethod() == ControlMethod::Port) {
-    if (net_test_connect(settings.getControlAddress(),
-                        settings.getControlPort())) {
+    if(!settings.autoControlPort() && net_test_connect(settings.getControlAddress(),
+                                                       settings.getControlPort())) {
       started();
       return;
     }
@@ -1014,8 +1039,20 @@ MainWindow::start()
     }
   }
 
-  /* Make sure the torrc we want to use really exists. */
   QString torrc = settings.getTorrc();
+
+  if(settings.bootstrap()) {
+    QString boottorrc = settings.bootstrapFrom();
+    vNotice(tr("Bootstrapping torrc from %1 to %2")
+        .arg(boottorrc).arg(torrc));
+    if(QFileInfo(boottorrc).exists()) {
+      if(QFile::copy(boottorrc, torrc)) {
+        settings.setBootstrap(false);
+      }
+    }
+  }
+
+  /* Make sure the torrc we want to use really exists. */
   if (!torrc.isEmpty()) {
     if (!QFileInfo(torrc).exists())
       touch_file(torrc, true);
@@ -1024,14 +1061,21 @@ MainWindow::start()
 
   /* Specify Tor's data directory, if different from the default */
   QString dataDirectory = settings.getDataDirectory();
+  QString expDataDirectory = expand_filename(dataDirectory);
   if (!dataDirectory.isEmpty())
-    args << "DataDirectory" << expand_filename(dataDirectory);
+    args << "DataDirectory" << expDataDirectory;
   
   if(settings.getControlMethod() == ControlMethod::Port) {
-    /* Add the intended control port value */
-    quint16 controlPort = settings.getControlPort();
-    if (controlPort)
-      args << "ControlPort" << QString::number(controlPort);
+    if(settings.autoControlPort()) {
+      args << "ControlPort" << "auto";
+      args << "SocksPort" << "auto";
+      args << "ControlPortWriteToFile" << QString("%1/port.conf").arg(expDataDirectory);
+    } else {
+      /* Add the intended control port value */
+      quint16 controlPort = settings.getControlPort();
+      if (controlPort)
+        args << "ControlPort" << QString::number(controlPort);
+    }
   } else {
     QString path = settings.getSocketPath();
     args << "ControlSocket" << path;
@@ -1125,11 +1169,59 @@ MainWindow::started()
   /* Remember whether we started Tor or not */
   _isVidaliaRunningTor = _torControl->isVidaliaRunningTor();
   /* Try to connect to Tor's control port */
-  if(settings.getControlMethod() == ControlMethod::Port)
-    _torControl->connect(settings.getControlAddress(),
-                        settings.getControlPort());
-  else
-    _torControl->connect(settings.getSocketPath());
+  if(settings.autoControlPort()) {
+    QString dataDirectory = settings.getDataDirectory();
+    QFile file(QString("%1/port.conf").arg(expand_filename(dataDirectory)));
+    int tries = 0, maxtries = 5;
+    while((!file.open(QIODevice::ReadOnly | QIODevice::Text)) and
+	  (tries++ < maxtries)) {
+      vWarn(QString("This is try number: %1.").arg(tries));
+#if defined(Q_WS_WIN)
+      Sleep(1000);
+#else
+      sleep(1);
+#endif
+    }
+
+    if(tries >= maxtries) {
+      vWarn("Couldn't read port.conf file");
+      if(_torControl->isRunning()) {
+        connectFailed(tr("Vidalia can't find out how to talk to Tor because it can't access this file: %1\n\nHere's the last error message:\n%2")
+                      .arg(file.fileName())
+                      .arg(file.errorString()));
+      } else {
+        vWarn("Tor isn't running!");
+        connectFailed(tr("It seems Tor has stopped running since Vidalia started it.\n\nSee the Advanced Message Log for more information."));
+      }
+
+      return;
+    }
+
+    QTextStream in(&file);
+    if(!in.atEnd()) {
+      QString line = in.readLine();
+      QStringList parts = line.split("=");
+      if(parts.size() != 2) return;
+      if(parts[0].trimmed() != "PORT") return;
+
+      QStringList addrPort = parts[1].split(":");
+      if(addrPort.size() != 2) return;
+
+      QHostAddress addr(addrPort.at(0));
+      _autoControlPort = addrPort.at(1).toInt();
+      _torControl->connect(addr, _autoControlPort);
+    }
+
+    file.close();
+  } else {
+    /* Try to connect to Tor's control port */
+    if(settings.getControlMethod() == ControlMethod::Port) {
+      _torControl->connect(settings.getControlAddress(),
+                          settings.getControlPort());
+      _autoControlPort = settings.getControlPort();
+    } else
+      _torControl->connect(settings.getSocketPath());
+  }
   setStartupProgress(STARTUP_PROGRESS_CONNECTING, tr("Connecting to Tor"));
 }
 
@@ -1636,20 +1728,20 @@ MainWindow::warnDangerousPort(quint16 port, bool rejected)
   QString application;
   switch (port) {
     case  23:
-     application = tr(", probably Telnet, ");
+     application = tr("(probably Telnet)");
      break;
 
     case 109:
     case 110:
     case 143:
-      application = tr(", probably an email client, "); 
+      application = tr("(probably an email client)"); 
       break;
 
     default:
-      application = " ";
+      application = "";
   }
 
-  QString text = tr("One of your applications%1appears to be making a "
+  QString text = tr("One of your applications %1 appears to be making a "
                     "potentially unencrypted and unsafe connection to port %2.")
                     .arg(application).arg(port);
 
@@ -1971,3 +2063,41 @@ MainWindow::installUpdatesFailed(const QString &errmsg)
 
 #endif
 
+QStringList
+MainWindow::updateBrowserEnv() {
+  TorSettings settings;
+  QStringList env = QProcess::systemEnvironment();
+  env << "TZ=UTC";
+  env << "MOZ_NO_REMOTE=1";
+
+  if(settings.autoControlPort()) {
+    QString errmsg, socks;
+    if(!(_torControl->getInfo("net/listeners/socks", socks, &errmsg))) {
+      vInfo(errmsg);
+      return env;
+    }
+
+    QStringList addrPort = socks.split(":");
+    if(addrPort.size() != 2) return env;
+
+    QHostAddress addr(addrPort.at(0));
+    quint16 port = addrPort.at(1).toInt();
+
+    env << QString("TOR_SOCKS_HOST=%1").arg(addr.toString());
+    env << QString("TOR_SOCKS_PORT=%1").arg(port);
+
+    vInfo(QString("Using automatic ControlPort and SocksPort configuration:\n"
+		  "   ControlPort=%1\n   SocksPort=%2\n   Host=%3\n   Configuration file:%4")
+	  .arg(_autoControlPort)
+	  .arg(port)
+	  .arg(addrPort.at(0))
+	  .arg(QString("%1/port.conf").arg(expand_filename(settings.getDataDirectory()))));
+  }
+
+  if(settings.getAuthenticationMethod() == TorSettings::PasswordAuth) {
+    env << QString("TOR_CONTROL_PASSWD=%1").arg(QString(_controlPassword.toAscii().toHex()));
+    env << QString("TOR_CONTROL_PORT=%1").arg(_autoControlPort);
+  }
+
+  return env;
+}
