@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -225,6 +225,9 @@ private:
   /** Sets the progress bar completion value to <b>progressValue</b> and sets
    * the status text to <b>description</b>. */
   void setStartupProgress(int percentComplete, const QString &description);
+  /** Adds the needed variables to the environment that the browser will
+   * need */
+  QStringList updateBrowserEnv();
 
   /** The current status of Tor. */
   TorStatus _status;
@@ -285,6 +288,8 @@ private:
   QAction* _actionShowNetworkMap;
   QAction* _actionNewIdentity;
 
+  quint16 _autoControlPort;
+
   Ui::MainWindow ui; /**< Qt Designer generated object. */
 };
 
