@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -54,7 +54,7 @@ public:
   ~Vidalia();
 
   /** Validates that all arguments were well-formed. */
-  static bool validateArguments(QString &errmsg);
+  bool validateArguments(QString &errmsg);
   /** Displays usage information for command-line args. */
   static void showUsageMessageBox();
   /** Returns true if the user wants to see usage information. */
