@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -89,6 +89,8 @@ private:
   /** Paints an integral using the supplied data. */
   void paintIntegral(QVector<QPointF> points, QColor color, qreal alpha = 1.0);
 
+  void resizeEvent(QResizeEvent *ev);
+
   /** Style with which the bandwidth data will be graphed. */
   GraphStyle _graphStyle;
   /** A QPainter object that handles drawing the various graph elements. */
@@ -101,6 +103,8 @@ private:
   QRect _rec;
   /** The maximum data value plotted. */
   qreal _maxValue;
+  /** The position of the local maximum in the displayed bandwidth */
+  int _maxPosition;
   /** The maximum number of points to store. */
   int _maxPoints;
   /** The total data sent/recv. */
