@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -75,6 +75,9 @@ private slots:
    * a more advanced way */
   void displayTorrcDialog();
 
+  /** Called when the user checks "Configure ControlPort automatically" */
+  void toggleAuto(bool);
+
 private:
   /** Returns the authentication method for the given <b>index</b>. */
   TorSettings::AuthenticationMethod indexToAuthMethod(int index);
