@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -46,7 +46,7 @@ BridgeDownloaderProgressDialog::setStatus(const QString &status)
 }
 
 void
-BridgeDownloaderProgressDialog::setDownloadProgress(int done, int total)
+BridgeDownloaderProgressDialog::setDownloadProgress(qint64 done, qint64 total)
 {
   ui.progressBar->setRange(0, total);
   ui.progressBar->setValue(done);
