@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -39,7 +39,7 @@ public slots:
    * <b>maximum</b> steps. If <b>value</b> and <b>maximum</b> are both 0,
    * then a "busy" progress bar is displayed.
    */
-  void setDownloadProgress(int value, int maximum);
+  void setDownloadProgress(qint64 value, qint64 maximum);
 
   /** Called when the bridge download completes successfully and discards 
    * the progress dialog with an Accept result code. <b>bridges</b>
