@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -120,6 +120,12 @@ private:
 
   /** Qt Designer generated object */
   Ui::ServerPage ui;
+
+  /** Used to store the dirport value and if the user wants to mirror the
+   * directory so that they can be emptied when selecting being a bridge and
+   * re-added when selecting relay */
+  QString _tmpDirPort;
+  bool _tmpMirror;
 };
 
 #endif
