@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -42,6 +42,12 @@ public:
   /** Returns true if Tor is configured to act as a bridge node. */
   bool isBridgeEnabled();
 
+  /** Sets to <b>enabled</b> whether Tor should be a non-exit node when acting
+   * as a server. */
+  void setNonExitEnabled(bool enable);
+  /** Returns true if Tor is configured to act as a non-exit node. */
+  bool isNonExitEnabled();
+
   /** Sets the server's ORPort value. */
   void setORPort(quint16 orPort);
   /** Gets the server's ORPort value. */
