@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -42,6 +42,9 @@
 #define SETTING_USE_RANDOM_PASSWORD "UseRandomPassword"
 #define SETTING_WARN_PLAINTEXT_PORTS    "WarnPlaintextPorts"
 #define SETTING_REJECT_PLAINTEXT_PORTS  "RejectPlaintextPorts"
+#define SETTING_BOOTSTRAP            "Bootstrap"
+#define SETTING_BOOTSTRAP_FROM       "BootstrapFrom"
+#define SETTING_AUTOCONTROL          "AutoControl"
 
 /** Default to using hashed password authentication */
 #define DEFAULT_AUTH_METHOD     PasswordAuth
@@ -88,6 +91,9 @@ TorSettings::TorSettings(TorControl *torControl)
   setDefault(SETTING_WARN_PLAINTEXT_PORTS, QList<QVariant>() << 23 << 109 
                                                              << 110 << 143);
   setDefault(SETTING_REJECT_PLAINTEXT_PORTS, QList<QVariant>());
+  setDefault(SETTING_BOOTSTRAP, false);
+  setDefault(SETTING_BOOTSTRAP_FROM, "");
+  setDefault(SETTING_AUTOCONTROL, false);
 }
 
 /** Applies any changes to Tor's control port or authentication settings. */
@@ -423,3 +429,38 @@ TorSettings::hashPassword(const QString &password)
                            .arg(base16_encode(key));
 }
 
+void
+TorSettings::setBootstrap(bool enabled)
+{
+  setValue(SETTING_BOOTSTRAP, enabled);
+}
+
+bool
+TorSettings::bootstrap() const
+{
+  return value(SETTING_BOOTSTRAP).toBool();
+}
+
+void
+TorSettings::setBootstrapFrom(const QString &from)
+{
+  setValue(SETTING_BOOTSTRAP_FROM, from);
+}
+
+QString
+TorSettings::bootstrapFrom() const
+{
+  return QDir::convertSeparators(value(SETTING_BOOTSTRAP_FROM).toString());
+}
+
+bool 
+TorSettings::autoControlPort() const
+{
+  return value(SETTING_AUTOCONTROL).toBool();
+}
+
+void 
+TorSettings::setAutoControlPort(const bool autoControl)
+{
+  setValue(SETTING_AUTOCONTROL, autoControl);
+}
