@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -72,6 +72,13 @@ public:
   /** Get the current control method */
   ControlMethod::Method getControlMethod() const;
 
+  /** Returns true if Vidalia will get the ControlPort automatically from
+   * Tor */
+  bool autoControlPort() const;
+
+  /** Sets whether Vidalia should get the ControlPort from Tor */
+  void setAutoControlPort(const bool auto);
+
   /** Set the control method */
   void setControlMethod(ControlMethod::Method method);
 
@@ -118,6 +125,15 @@ public:
    * "tor --hash-password foo". */
   static QString hashPassword(const QString &password);
 
+  /** Returns true if Vidalia needs to bootstrap the torrc file */
+  bool bootstrap() const;
+  /** Enables or disables bootstrap */
+  void setBootstrap(bool enabled);
+  /** Returns the path of the bootstrap torrc file */
+  QString bootstrapFrom() const;
+  /** Sets the location of the bootstrap torrc file */
+  void setBootstrapFrom(const QString &from);
+
 private:
   /** Returns the AuthenticationMethod enum value for the string
    * description of the authentication method given in <b>authMethod</b>. */
