@@ -12,11 +12,11 @@
 ### Start config ###
 
 # Location of the translated po files. Do not add the trailing slash. 
-translated="/home/runa/tor/vidaliahelp/po"
+translated="/home/runa/tor/vidalia/src/vidalia/help/content/po"
 
 # Location of the original and translated html files. Do not add the
 # trailing slash.
-html="/home/runa/tor/vidaliahelp/"
+html="/home/runa/tor/vidalia/src/vidalia/help/content"
 
 ### End config ###
 
@@ -28,7 +28,7 @@ for file in $po ; do
 
 	# Validate input and write results to a log file
 	validate_script="/home/runa/tor/translation/tools/validate.py"
-	validate_log="/home/runa/tor/validate/vidaliahelp-validate.log"
+	validate_log="/home/runa/tor/vidalia/src/vidalia/help/content/validate.log"
 	python "$validate_script" -i "$file" -l "$validate_log"
 
 	# Get the basename of the file we are dealing with.
