@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -15,7 +15,7 @@
 
 #include "StatusEventItem.h"
 
-#include <QTime>
+#include <QDateTime>
 #include <QPixmap>
 #include <QString>
 
@@ -25,15 +25,15 @@ StatusEventItem::StatusEventItem(QTreeWidget *parent)
 }
 
 void
-StatusEventItem::setTimestamp(const QTime &timestamp)
+StatusEventItem::setTimestamp(const QDateTime &timestamp)
 {
   setData(0, TimestampRole, timestamp);
 }
 
-QTime
+QDateTime
 StatusEventItem::timestamp() const
 {
-  return data(0, TimestampRole).toTime();
+  return data(0, TimestampRole).toDateTime();
 }
 
 void
@@ -101,8 +101,8 @@ StatusEventItem::toString() const
 bool
 StatusEventItem::operator<(const QTreeWidgetItem &other) const
 {
-  QTime a = data(0, TimestampRole).toTime();
-  QTime b = other.data(0, TimestampRole).toTime();
+  QDateTime a = data(0, TimestampRole).toDateTime();
+  QDateTime b = other.data(0, TimestampRole).toDateTime();
 
   return (a < b);
 }
