@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -18,7 +18,7 @@
 
 #include <QTreeWidgetItem>
 
-class QTime;
+class QDateTime;
 class QPixmap;
 class QString;
 
@@ -44,12 +44,12 @@ public:
   /** Sets the <b>timestamp</b> at which this status event occurred.
    * \sa timestamp()
    */
-  void setTimestamp(const QTime &timestamp);
+  void setTimestamp(const QDateTime &timestamp);
 
   /** Returns the timestamp at which this status event occurred.
    * \sa setTimestamp()
    */
-  QTime timestamp() const;
+  QDateTime timestamp() const;
 
   /** Sets the icon to be drawn along with this status event to <b>pixmap</b>.
    * \sa icon()
