@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -186,7 +186,7 @@ StatusEventWidget::find(const QString &text, bool highlight)
       continue;
 
     if (item->title().contains(text, Qt::CaseInsensitive)
-          || item->description().contains(text, Qt::CaseInsensitive)) {
+        || item->description().contains(text, Qt::CaseInsensitive)) {
       items.append(item);
       if (highlight)
         item->setSelected(true);
@@ -217,7 +217,7 @@ StatusEventWidget::addNotification(const QPixmap &icon,
 
   // Create the new notification item
   StatusEventItem *item = new StatusEventItem(this);
-  item->setTimestamp(QTime::currentTime());
+  item->setTimestamp(QDateTime::currentDateTime());
   item->setIcon(icon);
   item->setTitle(title);
   item->setDescription(description);
