@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -43,6 +43,8 @@ setup_crash_reporter()
   QString crashReporter = Vidalia::applicationDirPath() + "\\crashreporter.exe";
 #elif defined(Q_OS_MAC)
   QString crashReporter = Vidalia::applicationDirPath() + "/CrashReporter.app";
+#else
+  QString crashReporter = Vidalia::applicationDirPath() + "/crashreporter";
 #endif
   if (! QFileInfo(crashReporter).isExecutable()) {
     vWarn("Unable to find crash reporting application. Crash reporting will "
