@@ -3,9 +3,9 @@
 **  LICENSE file, found in the top level directory of this distribution. If you
 **  did not receive the LICENSE file with this file, you may obtain it from the
 **  Vidalia source package distributed by the Vidalia Project at
-**  http://www.vidalia-project.net/. No part of Vidalia, including this file,
-**  may be copied, modified, propagated, or distributed except according to the
-**  terms described in the LICENSE file.
+**  http://www.torproject.org/projects/vidalia.html. No part of Vidalia, 
+**  including this file, may be copied, modified, propagated, or distributed 
+**  except according to the terms described in the LICENSE file.
 */
 
 /*
@@ -110,8 +110,11 @@ RouterDescriptorView::display(QList<RouterDescriptor> rdlist)
 
     /* If the router is online, then show the uptime and bandwidth stats. */
     if (!rd.offline()) {
+      qint64 minBandwidth = (qint64)qMin(rd.observedBandwidth(), 
+                                qMin(rd.averageBandwidth(),
+                                     rd.burstBandwidth()));
       html.append(trow(tcol(b(tr("Bandwidth:")))  + 
-                       tcol(string_format_bandwidth(rd.observedBandwidth()))));
+                       tcol(string_format_bandwidth(minBandwidth))));
       html.append(trow(tcol(b(tr("Uptime:")))   + 
                        tcol(string_format_uptime(
                               adjustUptime(rd.uptime(), rd.published())))));
